FromRon

Trait FromRon 

pub trait FromRon<'a>
where Self: Sized + Deserialize<'a>,
{ // Provided method fn from_ron(ron: &'a str) -> Result<Self, Error> { ... } }
Trait with default method, that allows to create an implementor from given RON.

Provided Methods

fn from_ron(ron: &'a str) -> Result<Self, Error>

Creates an implementor from RON.

Errors

Will return Error with kind ErrorKind::DeserializingFailed if it fails to deserialize given string to implementor.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors